@@ -21,6 +21,7 @@ from debtcollector import moves
 import six
 
 from taskflow.types import notifier
+from taskflow.utils import misc
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -41,10 +42,7 @@ class Engine(object):
         self._flow = flow
         self._flow_detail = flow_detail
         self._backend = backend
-        if not options:
-            self._options = {}
-        else:
-            self._options = dict(options)
+        self._options = misc.ensure_dict(options)
         self._notifier = notifier.Notifier()
         self._atom_notifier = notifier.Notifier()
 
@@ -92,13 +90,26 @@ class Engine(object):
         could not be achieved.
         """
 
+    @abc.abstractmethod
+    def reset(self):
+        """Reset back to the ``PENDING`` state.
+
+        If a flow had previously ended up (from a prior engine
+        :py:func:`.run`) in the ``FAILURE``, ``SUCCESS`` or ``REVERTED``
+        states (or for some reason it ended up in an intermediary state) it
+        can be desireable to make it possible to run it again. Calling this
+        method enables that to occur (without causing a state transition
+        failure, which would typically occur if :py:meth:`.run` is called
+        directly without doing a reset).
+        """
+
     @abc.abstractmethod
     def prepare(self):
         """Performs any pre-run, but post-compilation actions.
 
         NOTE(harlowja): During preparation it is currently assumed that the
         underlying storage will be initialized, the atoms will be reset and
-        the engine will enter the PENDING state.
+        the engine will enter the ``PENDING`` state.
         """
 
     @abc.abstractmethod
